;  Carington:
;  A Model of Eldercare
;
; Bill Kennedy, wkennedy@gmu.edu
; 
; Ver 5: 21-23 Jan 2015: experiment: stress reduction (as fractional relief of caregiver)
; Ver 4: 14-20 Jan 2015: caregivers' burden in units of ADL & mental health level
; ver 3: 13 Jan 2015: health trajectory based on data
; ver 2: 16-17 Dec 2014 new structure, care-sources, 
; ver 1: 20-24 Nov 2014
;

; Basic design and operation:
;  two populations: elders, caregivers
;  each initialized with a set of parameters
;  and links consistant with population data
;
; Annually (each step):
;   population ages and events happen
;       health: moves probabilistically worse 
;   agents (some in dyads) consider and decide steps toward eldercare
;       using SD model of stress
;
; Outputs: statistics kept on the population
;

globals
[
  eldercount           ;; population figure
  caregivercount       ;; population figure
  connections          ;; list of connected agents
  percent              ;; parameter for generating a random variable
    
  ; stats
  married-stat         ;; percent married
  widowed-stat         ;; percent widowed
  single-stat          ;; percent single
  age-stat             ;; average age of elders
  count-stat           ;; number of elders (>60 years old)
  
  links-flag           ;; binary flag to show links  <= on interface
  temp-provider        ;; temp care source
  link-ref             ;; temp pointer to elder for whom a care-taker is linked

  stress-per-unit-step ;; stress from care giving (change per step)
  stress-life          ;; everything but care giving stress (change per step)
  
  stress0              ;; percent of caregivers at stress level 0
  stress1
  stress2
  stress3
  stress4p
  stressave            ;; average stress of family caregivers (spouse & kin)

  relief               ;; reduction in the stress level due to experimental conditions  
  
  totelders            ;; current number of elders  
]

turtles-own
[
  age                  ;; integer
  sex                  ;; M/F: male or female (use in longivity and care giving)
  health               ;; health status: excellent(E), very good (VG), G, fair(F), poor(P)
  mental-health-level  ;; mental health status: ver3: 0-5    ver2: no dementia(N), possible dementia (P), probable dementia (D)
  ADLs                 ;; count of activities of daily life that the agent cannot perform (0-7)
  married              ;; married, divorced, widowed, single
  caree                ;; link to carereceiver
  provider             ;; type: self, spouse, kin, professional, institution
  burden               ;; 2 digit combination of ADLs and dementia level 
  stress-current       ;; current (accumulator) stress amount
  stress-capacity      ;; how big the accumulator is
]

breed [elders elder]
breed [caregivers caregiver]

  
;====================
;
; button controls
;
; Init = initializes the model
; Step = moves the model forward 1 step
; Links = turns showing links on/off
; Run = runs forever
; 200 = runs for 200 steps
;
;====================

;========
to init
   clear-all
   reset-ticks
   set links-flag false
   set-default-shape turtles "person"
   repeat 100  [ make-elder ]               ; init 80 elders
   set totelders count elders
   set relief 1.0
end
   
   
;========
to go ; used by run and 200
  tick
  grow-older
  let n count elders
  repeat (100 - n) [ make-elder ]    ;  add new elders  
  collect-stats
  
  ; experiment 1
  if (ticks > initiation)
  [ set relief (7 * 18 - hrsPerWeek) / (7 * 18) ]
  
end


;=============
to show-links  ; used by links button
  set links-flag (not links-flag)
  ifelse not links-flag
     [ clear-links ]
     [ask caregivers
       [ if (not (caree = nobody))
         [ create-link-to caree ]
       ]
     ]     
end


;================
;
;    Elders 
;
;================

;=============
to make-elder
   create-elders 1
   [
        set age random-normal 71 7.0     ;; new to age group
        set size 2

        ; set sex
        ifelse random-float 1.0 < 0.59   ;; percent women
        [set sex "female"]
        [set sex "male"]

        ; set married status
        let x random-float 1.0
        ifelse x < 0.67                   ;; percent married
          [set married "married"]
          [set married "single"]          ;; rest single (or other categories divorsed, remaried, etc)      
    
        ; set general health
        init-general-health
          
        ; set mental health
        init-mental-health
        
        if (mental-health-level != 0)
          [ ask patch xcor ycor [set pcolor gray] ]

        set link-ref self  ; care provider initially set to self
        decide-care-source
                    
        ; plot elder    
        let xp (age - 40)
        if xp < 0   [set xp 0]
        if xp > 60  [set xp 60]
        setxy xp random-ycor
   ]
   
   ; create health care source for this new elder   
   add-care-source
end



;==============
to become-elder
   set breed elders

   ; set initial health
   ;    2012 report for non-hispanic white
   ;       age 65-74: 82% good-excellent  (E,VG,G) rest 18% (F,P)
   ;           75-84: 76%, 24% FP  change in 10 years: -6%
   ;           85+  : 69%; 31% FP  change in 10 years: -7%
   ;    will use 82=20+30+32 for E,VG,G  (0.8, 0.5, 0.18)
   ;    will use 18=10+8 for F,P  (0.8, 0)
   ;    as probabilities of transistion to a lower health category
   ;    note: not age dependent yet
   let x random-float 1.0
   ifelse x > 0.80          [set health "E"  set color blue   set ADLs 0]
     [ifelse x > 0.50       [set health "VG" set color green  set ADLs 1]
       [ifelse x > 0.18     [set health "G"  set color yellow set ADLs 2]
         [ifelse x > 0.10   [set health "F"  set color orange set ADLs 3]
                            [set health "P"  set color red    set ADLs 4]
         ]
       ]
     ]
  set mental-health-level -1
  init-mental-health
  set color gray
end



;==================
to grow-older
  ask turtles
  [
    set age (age + 1)
    if (breed = caregivers) and (age > 64.5) and (age < 65.5) 
       [ become-elder]

    if color = gray
    [ set health "E"
      set color blue
    ]
    
    ; general health degrades with age
    degrade-general-health
    degrade-mental-health
          
    ; update mental health
    if (breed = elders) and (mental-health-level = -1) [init-mental-health]  ; once have, keep
    
    ; update caregiver burden each step
    if (breed = caregivers)  [ update-burden ]
    
    ; check mortality
    check-mortality
    
    if links-flag 
      [ if (not (caree = nobody))
        and (not (caree = 0))
        [ create-link-to caree ]
      ]
     
    ; scale plotted x based on age
    ask patch xcor ycor [set pcolor black]
    let xp (age - 40)
    if xp < 0   [set xp 0]
    if xp > 60  [set xp 60]
    setxy xp ycor
    if (breed = elders) and (mental-health-level = 1)
      [ ask patch xcor ycor [set pcolor gray] ]
    if (breed = elders) and (mental-health-level = 2)
      [ ask patch xcor ycor [set pcolor yellow] ]
    if (breed = elders) and (mental-health-level = 3)
      [ ask patch xcor ycor [set pcolor orange] ]
    if (breed = elders) and (mental-health-level > 3)
      [ ask patch xcor ycor [set pcolor red] ]

    ; remove caregivers with no patient
    if (caree = nobody) 
    [ ask patch xcor ycor [set pcolor black]
      die]
    
  ]
end


;======================
;
;   General Health
;
;======================

;======================
to init-general-health
          ; set initial health
        ;    2012 report for non-hispanic white
        ;       age 65-74: 82% good-excellent  (E,VG,G)  rest 18% (F,P)
        ;           75-84: 76%, 24% FP  change in 10 years: -6%
        ;           85+  : 69%; 31% FP  change in 10 years: -7%
        ;    will use 82=20+30+32 for E,VG,G  (0.8, 0.5, 0.18)
        ;    will use 18=10+8 for F,P  (0.8, 0)
        ;    note: not age dependent yet
        let x random-float 1.0
        ifelse x > 0.80        [set health "E"  set color blue   set ADLs 0]
          [ifelse x > 0.50     [set health "VG" set color green  set ADLs 1]
            [ifelse x > 0.18   [set health "G"  set color yellow set ADLs 2]
              [ifelse x > 0.10 [set health "F"  set color orange set ADLs 3]
                               [set health "P"  set color red    set ADLs 4]
              ]
            ]
          ]
end


;========================
to degrade-general-health
   let x random-float 1.0
   ; prob from Table 1 of ODD
   if (age >= 60) and (age < 65)  and (x <= 0.0498) [step-health]
   if (age >= 65) and (age < 70)  and (x <= 0.0744) [step-health]
   if (age >= 70) and (age < 75)  and (x <= 0.1123) [step-health]
   if (age >= 75) and (age < 80)  and (x <= 0.1748) [step-health]
   if (age >= 80) and (age < 85)  and (x <= 0.2759) [step-health]
   if (age >= 85) and (age < 90)  and (x <= 0.4296) [step-health]
   if (age >= 90) and (age < 95)  and (x <= 0.6153) [step-health]
   if (age >= 95) and (age < 100) and (x <= 0.7834) [step-health]
   if (age >= 100)  [remove-agent]
end


;=============
to step-health
   ifelse health = "E"       [set health "VG" set color green  set ADLs (ADLs + 1)]
     [ifelse health = "VG"   [set health "G"  set color yellow set ADLs (ADLs + 1)]
       [ifelse health = "G"  [set health "F"  set color orange set ADLs (ADLs + 1)]
         [if health = "F"    [set health "P"  set color red    set ADLs (ADLs + 1)]
         ]
       ]
     ]
   
   if (breed = elders) [reconsider-provider]
end  


;==================
to check-mortality
   let x random-float 1.0
   ; prob from Table 1 of ODD
   if (age >= 60) and (age < 65)  and (x <= 0.0498) [remove-agent]
   if (age >= 65) and (age < 70)  and (x <= 0.0744) [remove-agent]
   if (age >= 70) and (age < 75)  and (x <= 0.1123) [remove-agent]
   if (age >= 75) and (age < 80)  and (x <= 0.1748) [remove-agent]
   if (age >= 80) and (age < 85)  and (x <= 0.2759) [remove-agent]
   if (age >= 85) and (age < 90)  and (x <= 0.4296) [remove-agent]
   if (age >= 90) and (age < 95)  and (x <= 0.6153) [remove-agent]
   if (age >= 95) and (age < 100) and (x <= 0.7834) [remove-agent]
   if (age >= 100)  [remove-agent]
end


;==============
to remove-agent
;   ask turtles with [caree = self] 
   ask patch xcor ycor [set pcolor black]
   die
end     



;======================
;
;   Mental Health
;
;======================

;======================
to init-mental-health
   let x random-float 1.0
   let prob-d 0
   let poss-d 0
   
   ; set thresholds
   if (age >= 65) and (age <= 70)
   [ set prob-d 0.039
     set poss-d 0.099 ]
   if (age >= 71) and (age <= 79)
   [ set prob-d 0.082
     set poss-d 0.190 ]
   if (age >= 80) and (age <= 89)
   [ set prob-d 0.203
     set poss-d 0.357 ]
   if (age >= 90)
   [ set prob-d 0.384
     set poss-d 0.545 ]
   
   ; set mental health based on age  
   ifelse (x < prob-d)
     [set mental-health-level 2]   ;"D"]
     [ifelse (x < poss-d)
       [set mental-health-level 1] ;"P"]
       [set mental-health-level 0] ;"N"]
     ]
end
  

;=======================
to degrade-mental-health
   let x random-float 1.0
   ; prob from Table 4 of ODD
   if (age >= 60) and (age < 65)  and (x <= 0.0031) [set mental-health-level (mental-health-level + 1)]
   if (age >= 65) and (age < 70)  and (x <= 0.0062) [set mental-health-level (mental-health-level + 1)]
   if (age >= 70) and (age < 75)  and (x <= 0.0125) [set mental-health-level (mental-health-level + 1)]
   if (age >= 75) and (age < 80)  and (x <= 0.0250) [set mental-health-level (mental-health-level + 1)]
   if (age >= 80) and (age < 85)  and (x <= 0.0500) [set mental-health-level (mental-health-level + 1)]
   if (age >= 85) and (age < 90)  and (x <= 0.1000) [set mental-health-level (mental-health-level + 1)]
   if (age >= 90) and (age < 95)  and (x <= 0.2000) [set mental-health-level (mental-health-level + 1)]
   if (age >= 95) and (age < 100) and (x <= 0.4000) [set mental-health-level (mental-health-level + 1)]
end




;======================
;
;   Providing Care
;
;======================

  
;====================
to decide-care-source
  if (married = "married")
     [ifelse (health = "E") or (health = "VG")
       [set temp-provider "self"]
       [ifelse (health = "G")
         [set temp-provider "spouse"]
         [set temp-provider "kin"]
       ]
     ]

  if (married = "single") 
  [
    ifelse (health = "E") or (health = "VG")
    [ set temp-provider "self"]
    [ ifelse (health = "P")
      [set temp-provider "institution"]
      [set temp-provider "professional"]
    ]
  ]
  
  set provider temp-provider
end


;==================
to add-care-source
   ; create care giver   
   if (temp-provider != "self")
   [
     create-caregivers 1
     [
      set age random-normal 45 6.75     ;; mean 75.78, SD 6.75
      if (temp-provider = "institution")
         [set shape "house"
          set color white]
      if (temp-provider = "spouse")
         [set color pink]
      if (temp-provider = "professional")
         [set color cyan + 1]
      if (temp-provider = "kin")
         [set color brown]
      if ( not (temp-provider = "institution")
           and not (temp-provider = "spouse")
           and not (temp-provider = "professional")
           and not (temp-provider = "kin") )
           [print "adding care source problem: " print temp-provider]

      set size 2
      set stress-capacity 3
      
      ; for plotting of caregivers, place them at age-40 withinin display limits
      let xp (age - 40)
      if xp < 0   [set xp 0]
      if xp > 60  [set xp 60]
      setxy xp random-ycor
      
;     set caree one-of elders
      if links-flag [ create-link-to link-ref ]
      set caree link-ref
    ]
   ]
end


;=====================
to reconsider-provider
  if (health = "P")
    [set provider "institution"]
  ifelse (health = "F") and (married = "married")
    [set provider "professional"]
    [set provider "institution"]

  ; policy incentive
;  if (ticks > initiation) 
;     and (random-float 1.0 < incentive) ; incentive high enough to change
;     and (provider != "kin")
;     and (provider != "spouse")
;  [    
;    set provider "kin"
;  ]
    
end
    

;==================
to update-burden
  let ADL 0
  let MHL 0
  ; get general & mental health of receipent
  if not (caree = nobody)
     [ask caree 
       [ if ((provider = "spouse") or (provider = "kin"))
            [set ADL ADLs
             set MHL mental-health-level]
       ]
     ]

  ; SD model of stress of the caregiver
  let old-stress stress-current
  let stress-change (ADL + MHL - old-stress) * relief

  ; in current year, stress higher due to stress change
  if (stress-current + (2 * stress-change) > stress-capacity) [reconsider-provider]
  
  ; then decays down to simple sum
  set stress-current ( stress-current + stress-change )

end

;====================
;
;   Data Collecting
;
;====================
  
;================
to collect-stats
  ; initialize variables
  let married-temp 0
  let widowed-temp 0
  let single-temp 0
  let age-temp 0
  set count-stat 0
  
  ask elders
  [
    if married = "married"
       [set married-temp (married-temp + 1)]
    if married = "widowed"
       [set widowed-temp (widowed-temp + 1)]
    if married = "single"
       [set single-temp  (single-temp + 1)]
    set age-temp (age-temp + age)
    set count-stat (count-stat + 1)
  ]
  
  ; convert to integers
  set married-stat 100 * (married-temp / count-stat)
  set widowed-stat 100 * (widowed-temp / count-stat)
  set single-stat  100 * (single-temp  / count-stat)
  set age-stat (age-temp / count-stat)
  
  ; collect and calc average number of caregivers with diff stress levels  
  let temptot  count caregivers with [(color = pink) or (color = brown)]
  set stress0  count caregivers with [(color = pink) or (color = brown) and (stress-current < 1.0)]
  set stress1  count caregivers with [(color = pink) or (color = brown) and (stress-current > 1.0) and (stress-current <= 2.0)]
  set stress2  count caregivers with [(color = pink) or (color = brown) and (stress-current > 2.0) and (stress-current <= 3.0)]
  set stress3  count caregivers with [(color = pink) or (color = brown) and (stress-current > 3.0) and (stress-current <= 4.0)] 
  set stress4p count caregivers with [(color = pink) or (color = brown) and (stress-current > 4.0)]
  ;  convert to percent
  set stress0  (100 * stress0  / temptot)
  set stress1  (100 * stress1  / temptot)
  set stress2  (100 * stress2  / temptot)
  set stress3  (100 * stress3  / temptot)
  set stress4p (100 * stress4p / temptot)

  ; collect and calc ave stress info for spouses and kin
  let totstress 0
  ask caregivers with [(color = pink) or (color = brown)]
      [set totstress (totstress + stress-current)]    
  set stressave (totstress / temptot)  
   
   
end
@#$#@#$#@
GRAPHICS-WINDOW
350
10
927
347
-1
16
9.3
1
10
1
1
1
0
0
1
1
0
60
-16
16
0
0
1
steps
30.0

BUTTON
14
77
69
110
Init
init
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
74
77
129
110
step
go
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

TEXTBOX
350
358
988
403
40                    50                    60                    70                  80                   90                100+\n                                                            Age ->
12
0.0
1

TEXTBOX
60
10
301
40
Carington Ver 5.0
24
105.0
1

MONITOR
145
123
233
168
Spouse+Kin
count caregivers with [color = pink or color = 35]
4
1
11

MONITOR
12
123
66
168
Elders
count elders
4
1
11

BUTTON
250
77
305
110
200
while [ticks < 200] [go]
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

PLOT
12
175
310
295
Elder Health Status (as displayed)
Year
Percent
0.0
100.0
0.0
100.0
true
true
"" ""
PENS
"Excellent" 1.0 0 -13345367 true "" "plot 100 * (count elders with [color = blue])/(1 + count elders)"
"Very Good" 1.0 0 -13840069 true "" "plot 100 * (count elders with [color = green])/(1 + count elders)"
"Good" 1.0 0 -4079321 true "" "plot 100 * (count elders with [color = yellow])/(1 + count elders)"
"Fair" 1.0 0 -955883 true "" "plot 100 * (count elders with [color = orange])/(1 + count elders)"
"Poor" 1.0 0 -2674135 true "" "plot 100 * (count elders with [color = red])/(1 + count elders)"

MONITOR
70
123
143
168
Self
count elders with [provider = \"self\"]
17
1
11

PLOT
330
400
627
550
Caregivers
Year
Percent
0.0
100.0
0.0
100.0
true
true
"" ""
PENS
"Spouse" 1.0 0 -2064490 true "" "plot 100 * (count elders with [provider = \"spouse\"])/(1 + count elders)"
"Kin" 1.0 0 -6459832 true "" "plot 100 * (count elders with [provider = \"kin\"])/(1 + count elders)"
"Professional" 1.0 0 -8990512 true "" "plot 100 * (count elders with [provider = \"professional\"])/(1 + count elders)"
"Institution" 1.0 0 -14070903 true "" "plot 100 * (count elders with [provider = \"institution\"])/(1 + count elders)"

TEXTBOX
475
562
994
596
            Setting for how much relief:              When it is initiated:
14
0.0
1

SLIDER
511
579
721
612
hrsPerWeek
hrsPerWeek
0
168
84
1
1
hrs per week
HORIZONTAL

SLIDER
753
580
925
613
initiation
initiation
0
250
100
1
1
steps
HORIZONTAL

PLOT
631
400
928
550
Spouse & Kin Caregiver Stress
Year
Percent
0.0
100.0
0.0
100.0
true
true
"" ""
PENS
"Level 0" 1.0 0 -14439633 true "" "plot stress0"
"Level 1" 1.0 0 -4079321 true "" "plot stress1"
"Level 2" 1.0 0 -955883 true "" "plot stress2"
"Level 3" 1.0 0 -2674135 true "" "plot stress3"
"Level 4+" 1.0 0 -5825686 true "" "plot stress4p"

BUTTON
134
77
189
110
Links
show-links
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

PLOT
13
305
310
455
Elder ADLs
Year
Percent
0.0
100.0
0.0
100.0
true
true
"" ""
PENS
"no ADLs" 1.0 0 -13345367 true "" "plot 100 * (count elders with [ADLs =  0]) / ( 1 + totelders)"
"1 ADLs" 1.0 0 -10899396 true "" "plot 100 * (count elders with [ADLs =  1]) / ( 1 + totelders)"
"2 ADLs" 1.0 0 -4079321 true "" "plot 100 * (count elders with [ADLs =  2]) / ( 1 + totelders)"
"3 ADLs" 1.0 0 -955883 true "" "plot 100 * (count elders with [ADLs =  3]) / ( 1 + totelders)"
"4+ ADLs" 1.0 0 -2674135 true "" "plot 100 * (count elders with [ADLs >= 4]) / ( 1 + totelders)"

PLOT
14
464
310
614
Elder Mental Health Levels
Year
Percent
0.0
100.0
0.0
100.0
true
true
"" ""
PENS
"none" 1.0 0 -13345367 true "" "plot 100 * count elders with [mental-health-level =  0] / (1 + count elders)"
"Level 1" 1.0 0 -4079321 true "" "plot 100 * count elders with [mental-health-level =  1] / (1 + count elders)"
"Level 2" 1.0 0 -955883 true "" "plot 100 * count elders with [mental-health-level =  2] / (1 + count elders)"
"Level 3+" 1.0 0 -2674135 true "" "plot 100 * count elders with [mental-health-level >= 3] / (1 + count elders)"

MONITOR
235
123
307
168
Inst+Prof
count caregivers with [shape = \"house\" or color = 86]
17
1
11

TEXTBOX
353
574
487
624
Experimental Variables:
16
15.0
1

BUTTON
192
77
247
110
Run
go
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

TEXTBOX
92
40
242
58
George Mason University
11
64.0
1

@#$#@#$#@
## WHAT IS IT?

See associated ODD+D, version 3, 13 Jan 2015.

## HOW IT WORKS

(what rules the agents use to create the overall behavior of the model)

## HOW TO USE IT

(how to use the model, including a description of each of the items in the Interface tab)

## THINGS TO NOTICE

(suggested things for the user to notice while running the model)

## THINGS TO TRY

(suggested things for the user to try to do (move sliders, switches, etc.) with the model)

## EXTENDING THE MODEL

(suggested things to add or change in the Code tab to make the model more complicated, detailed, accurate, etc.)

## NETLOGO FEATURES

(interesting or unusual features of NetLogo that the model uses, particularly in the Code tab; or where workarounds were needed for missing features)

## RELATED MODELS

(models in the NetLogo Models Library and elsewhere which are of related interest)

## CREDITS AND REFERENCES

(a reference to the model's URL on the web if it has one, as well as any other necessary credits, citations, and links)
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

sheep
false
15
Circle -1 true true 203 65 88
Circle -1 true true 70 65 162
Circle -1 true true 150 105 120
Polygon -7500403 true false 218 120 240 165 255 165 278 120
Circle -7500403 true false 214 72 67
Rectangle -1 true true 164 223 179 298
Polygon -1 true true 45 285 30 285 30 240 15 195 45 210
Circle -1 true true 3 83 150
Rectangle -1 true true 65 221 80 296
Polygon -1 true true 195 285 210 285 210 240 240 210 195 210
Polygon -7500403 true false 276 85 285 105 302 99 294 83
Polygon -7500403 true false 219 85 210 105 193 99 201 83

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

wolf
false
0
Polygon -16777216 true false 253 133 245 131 245 133
Polygon -7500403 true true 2 194 13 197 30 191 38 193 38 205 20 226 20 257 27 265 38 266 40 260 31 253 31 230 60 206 68 198 75 209 66 228 65 243 82 261 84 268 100 267 103 261 77 239 79 231 100 207 98 196 119 201 143 202 160 195 166 210 172 213 173 238 167 251 160 248 154 265 169 264 178 247 186 240 198 260 200 271 217 271 219 262 207 258 195 230 192 198 210 184 227 164 242 144 259 145 284 151 277 141 293 140 299 134 297 127 273 119 270 105
Polygon -7500403 true true -1 195 14 180 36 166 40 153 53 140 82 131 134 133 159 126 188 115 227 108 236 102 238 98 268 86 269 92 281 87 269 103 269 113

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270

@#$#@#$#@
NetLogo 5.2.0
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
<experiments>
  <experiment name="experiments" repetitions="30" runMetricsEveryStep="true">
    <setup>init</setup>
    <go>go</go>
    <timeLimit steps="200"/>
    <metric>ticks</metric>
    <metric>count caregivers with [(color = pink) or (color = brown)]</metric>
    <metric>stressave</metric>
    <enumeratedValueSet variable="hrsPerWeek">
      <value value="8"/>
      <value value="40"/>
      <value value="70"/>
      <value value="84"/>
      <value value="98"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initiation">
      <value value="100"/>
    </enumeratedValueSet>
  </experiment>
</experiments>
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 0.0 1.0
0.0 1 1.0 0.0
0.2 0 0.0 1.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180

@#$#@#$#@
0
@#$#@#$#@
